@@ -195,21 +195,21 @@ print.semlbci <- function(x,
         out$label <- NULL
       }
     class(out) <- "data.frame"
-    out$lbci_lb <- formatC(out$lbci_lb, digits, format = "f")
+    out$lbci_lb <- formatC(out$lbci_lb, digits, format = "f", mode = "double")
     if ("est.std" %in% colnames(x)) {
         standardized <- TRUE
-        out$est.std <- formatC(out$est.std, digits, format = "f")
+        out$est.std <- formatC(out$est.std, digits, format = "f", mode = "double")
       } else {
         standardized <- FALSE
-        out$est <- formatC(out$est, digits, format = "f")
+        out$est <- formatC(out$est, digits, format = "f", mode = "double")
       }
-    out$lbci_ub <- formatC(out$lbci_ub, digits, format = "f")
-    out$ci_org_lb <- formatC(out$ci_org_lb, digits, format = "f")
-    out$ci_org_ub <- formatC(out$ci_org_ub, digits, format = "f")
-    out$ratio_lb <- formatC(out$ratio_lb, digits, format = "f")
-    out$ratio_ub <- formatC(out$ratio_ub, digits, format = "f")
-    out$cl_lb <- formatC(out$cl_lb, digits, format = "f")
-    out$cl_ub <- formatC(out$cl_ub, digits, format = "f")
+    out$lbci_ub <- formatC(out$lbci_ub, digits, format = "f", mode = "double")
+    out$ci_org_lb <- formatC(out$ci_org_lb, digits, format = "f", mode = "double")
+    out$ci_org_ub <- formatC(out$ci_org_ub, digits, format = "f", mode = "double")
+    out$ratio_lb <- formatC(out$ratio_lb, digits, format = "f", mode = "double")
+    out$ratio_ub <- formatC(out$ratio_ub, digits, format = "f", mode = "double")
+    out$cl_lb <- formatC(out$cl_lb, digits, format = "f", mode = "double")
+    out$cl_ub <- formatC(out$cl_ub, digits, format = "f", mode = "double")
     call_org <- attr(out, "call")
     if (drop_no_lbci) {
         out <- out[!is.na(out$status_lb), ]
@@ -298,7 +298,10 @@ print.semlbci <- function(x,
           msg <- c(msg,
             paste0("* ok_l, ok_u: Whether the search encountered any problem. ",
                   "If no problem encountered, it is equal to 0. Any value ",
-                  "other than 0 indicates something was wrong in the search."))
+                  "other than 0 indicates something was wrong in the search. ",
+                  "Try running 'semlbci()' again, setting 'semlbci_out' to this output, ",
+                  "and set 'try_k_more_times' to a positive number greater than ",
+                  "2 (the default), e.g., 3 to 5."))
           }
         if (standardized) {
             msg <- c(msg,
@@ -562,7 +565,10 @@ print_semlbci_text <- function(x,
             tmp0 <- "- Status: "
             tmp <- paste0(tmp0, "Whether the search encountered any problem for the two bounds. ",
                     "If no problem encountered, the code is 0 (displayed as 'OK'). Any value ",
-                    "other than 0 indicates something was wrong in the search.")
+                    "other than 0 indicates something was wrong in the search. ",
+                    "Try running 'semlbci()' again, setting 'semlbci_out' to this output, ",
+                    "and set 'try_k_more_times' to a positive number greater than ",
+                    "2 (the default), e.g., 3 to 5.")
             tmp <- strwrap(tmp,
                            indent = 0,
                            exdent = nchar(tmp0))
@@ -699,7 +705,8 @@ format_ratio <- function(object,
     where <- match.arg(where)
     tmp <- formatC(as.numeric(object),
                    digits = digits,
-                   format = "f")
+                   format = "f",
+                   mode = "double")
     tmp2 <- tmp
     if (where == "left") {
         tmp2[which(!flag)] <- paste0(" ", tmp[which(!flag)])
